NfcCard class abstract

Implementers

Constructors

NfcCard({required String id, required TagCategory type, required String protocol, required bool hasNdef, required bool canWrite, required int capacity, required bool isLocked, required Map<String, dynamic> raw})
NfcCard.create(TagPayload payload)
factory

Properties

canWrite → bool
final
capacity → int
final
hashCode → int
The hash code for this object.
no setterinherited
hasNdef → bool
final
id → String
final
isLocked → bool
final
protocol → String
final
raw → Map<String, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TagCategory
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited