NfcMockBridge class abstract

Constructors

NfcMockBridge()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exchange<T>(String id, T data) Future<T>
fetchNdef(String id) Future<List<NDEFRecord>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
poll() NfcCard
pullBlock(String id, int i) Future<Uint8List>
pushBlock(String id, int i, dynamic d) Future<void>
pushNdef(String id, List<NDEFRecord> msg) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited