VicinityCard class

Inheritance

Constructors

VicinityCard(TagPayload p, Map<String, dynamic> r)

Properties

canWrite → bool
finalinherited
capacity → int
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNdef → bool
finalinherited
id → String
finalinherited
isLocked → bool
finalinherited
protocol → String
finalinherited
raw → Map<String, dynamic>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TagCategory
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBlock(int index) → Future<Uint8List>
toString() → String
A string representation of this object.
inherited
writeBlock(int index, dynamic data) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited