WebUsbDriver class

Constructors

WebUsbDriver()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

exchange(String hex) → Future<String>
halt(bool close) → Future<void>
listen(int timeout, bool probe) → Future<String>