NdefEnabledCard class
- Inheritance
- Mixed-in types
Constructors
-
NdefEnabledCard(TagPayload p, Map<
String, dynamic> r)
Properties
- canWrite → bool
-
finalinherited
- capacity → int
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNdef → bool
-
finalinherited
- id → String
-
finalinherited
- isLocked → bool
-
finalinherited
- p → TagPayload
-
finalinherited
- protocol → String
-
finalinherited
-
r
→ Map<
String, dynamic> -
finalinherited
-
raw
→ Map<
String, dynamic> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → TagCategory
-
finalinherited
Methods
-
lock(
) → Future< void> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → Future< List< NDEFRecord> > -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
List< NDEFRecord> msg) → Future<void> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited