NfcPlus class

Constructors

NfcPlus()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

state Stream<NfcPhase>
no setter
stream Stream<NfcCard>
no setter

Static Methods

capture({Duration? timeout, bool feedback = true}) Future<NfcCard>
checkStatus() Future<NfcSupport>
debug() → void
mock(NfcMockBridge bridge) → void
pause() → void
resetMock() → void
resume() → void
start({Duration cooldown = const Duration(seconds: 2)}) Future<void>
stop() Future<void>
writeNdef(dynamic content) Future<void>